@@ -1,7 +1,9 @@
 from fastspider.core.spiders.light_spider import LightSpider
+from fastspider.core.spiders.spider import Spider
 from fastspider.http.request.request import Request
 
 __all__ = [
 	"LightSpider",
 	"Request",
+	"Spider",
 ]
