@@ -5,7 +5,7 @@ Email: 779598160@qq.com
 
 CreateTime: 2021/07/29
 
-Desc: fastspider核心爬虫AirSpider的基类代码
+Desc: fastspider核心爬虫LightSpider的基类代码
 """
 from fastspider.http.request.request import Request
 
@@ -42,3 +42,4 @@ class LightBase(object):
 	def name(self):
 		# 示例方法, 获取类名
 		return self.__class__.__name__
+
