@@ -1,5 +1,6 @@
 # encoding=utf-8
-
+import datetime
+import pickle
 import time
 
 from fastspider.settings import common
@@ -97,3 +98,25 @@ def time_to_timestamp(strtime):
 	"""
 	timeArray = time.strptime(strtime, "%Y-%m-%d %H:%M")
 	return int(time.mktime(timeArray))
+
+
+def get_current_timestamp():
+	"""
+		获取当前时间的时间戳
+	"""
+	return int(time.time())
+
+
+def format_date(format="%Y-%m-%d %H:%M:%S"):
+	"""
+		格式化日期
+	"""
+	return datetime.datetime.now().strftime(format)
+
+
+def dumps_obj(obj):
+	return pickle.dumps(obj)
+
+
+def loads_obj(obj_str):
+	return pickle.loads(obj_str)
